@@ -4,15 +4,15 @@ CONFIG = {
     "DEV": {
         "LOCAL": {
             "TEST_URL": "https://rec-dev.shinsegae.ai/v1",
-            "MLOPS_REC_URL": "https://rec-dev.shinsegae.ai/v1",
-            "MLOPS_DATA_URL": "https://data-dev.shinsegae.ai/v1",
+            "MLOPS_REC_URL": "http://internal-rec-dev-v1",
+            "MLOPS_DATA_URL": "http://internal-data-dev-v1.shinsegae.ai",
         }
     },
     "STG": {
         "LOCAL": {
             "TEST_URL": "https://rec-stg.shinsegae.ai/v1",
-            "MLOPS_REC_URL": "https://rec-stg.shinsegae.ai/v1",
-            "MLOPS_DATA_URL": "https://data-stg.shinsegae.ai/v1",
+            "MLOPS_REC_URL": "http://internal-emart-search-stg-v1.shinsegae.ai",
+            "MLOPS_DATA_URL": "http://internal-data-stg-v1.shinsegae.ai",
         }
     },
 }
